#
# spec file for package tkgate
#
# Copyright (c) 2012 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           tkgate
Version:        1.8.7
Release:        lp150.8.16
License:        GPL-2.0+
Summary:        Event driven digital circuit simulator with a tcl/tk interface
Url:            http://www.tkgate.org/
Group:          Productivity/Scientific/Electronics
Source:         %{name}-%{version}.tar.bz2
Source2:        tkgate.desktop
Source3:        tkgate.png
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch1:         tkgate-config.h.patch
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch2:         tkgate-elistbox.patch
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch3:         tkgate-honour-localdir.patch
# PATCH-MISSING-TAG -- See http://en.opensuse.org/Packaging/Patches
Patch4:         tkgate-manpages.patch
# PATCH-FIX-UPSTREAM fix incorrect fsf address
Patch5:         tkgate-incorrect-fsf-address.diff
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-devel
%if 0%{?suse_version} > 1210 || 0%{?fedora}
BuildRequires:  imake
BuildRequires:  libX11-devel
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
%else
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXext-devel
BuildRequires:  xorg-x11-libXmu-devel
BuildRequires:  xorg-x11-libXt-devel
%endif
BuildRequires:  desktop-file-utils 
Requires:       tcl >= 8
Requires:       tk >= 8
Vendor:         openSUSE-Education
%if 0%{?suse_version} <= 1230
%define         tkversion 8.5
%define         tklibversion 8.5
%define         tclversion 8.5
%define         tcllibversion 8.5
%else
%define         tkversion 8.6
%define         tklibversion 8.6
%define         tclversion 8.6
%define         tcllibversion 8.6
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
TkGate is a event driven digital circuit simulator with a tcl/tk-based
graphical editor. TkGate supports a wide range of primitive circuit
elements as well as user-defined modules for hierarchical design.
The distribution comes with a number of tutorial and example circuits
which can be loaded through the "Help" menu. The example circuits include
a simple CPU, programmed to run the Animals game.

TkGate Features:
- Easy to use point-and-click user interface.
- Customizable color configuration.
- Intelligent placement and movement of wires.
- Multi-bit buses.
- Hierarchical design through user defined modules.
- Six valued logic including 0, 1, floating, unknown, "low" and "high".
- Wide range of circuit elements including:
-      Basic gates (AND, OR, etc.)
-      Switch-level NMOS and PMOS transistors
-      Tristate buffers
-      Alu components (Adders, shifters, multipliers)
-      Memory elements (Registers, RAMs, ROMs)
-      A "tty" element which allows the creation of interactive circuits.
- Graphical display of simulation results.
- Breakpoints, single-step and clock-step simulator control.
- Includes a generic microcode/macrocode compiler for creating memory
  initialization files.
- Simulations can be controlled through the GUI or through script files.
- Verilog-like save file format.
- Hyperlinks to move about in circuit or load other files.
- Can be configured to use Japanese interface (see README file).
- Supports static critical path analysis.

%prep
%setup -q
%patch1
%patch2
%patch3
%patch4
%patch5 -p1 
find . -name "*.v.orig" -exec rm {} \;
sed -i "s|@@TKVERSION@@|%{tkversion}|g; \
        s|@@TCLVERSION@@|%{tclversion}|g; \
        s|@@TCLLIBVERSION@@|%{tcllibversion}|g; \
        s|@@TKLIBVERSION@@|%{tklibversion}|g" config.h

%ifarch x86_64
sed -i "s|#define TKGATE_ARCHITECTURE     32|#define TKGATE_ARCHITECTURE     64|g; \
        s|#define USELONGLONG*0|#define USELONGLONG        1|g" config.h
%endif

#Fix file-contains-date-and-time
datetime=$(date --date "`stat --format %y config.h`" +"%b %d %H:%M %Y")
sed -i 's/.__DATE__,__TIME__/ \"'"$datetime"'\\n\"/g' src/tkgate/tkgate.c

%build
export TCL_LIBRARY="%{_libdir}"
export TK_LIBRARY="%{_libdir}"
%configure
%if 0%{?suse_version} >= 1310
echo '#define USE_INTERP_RESULT 1' >> config.h
%endif
%{__make} %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_libdir}/
make DESTDIR=$RPM_BUILD_ROOT install install.man
mv %{buildroot}%{buildroot}%{_bindir}/tkgate %{buildroot}%{_bindir}/
mv %{buildroot}%{buildroot}%{_datadir}/tkgate/libexec/tkgate %{buildroot}%{_libdir}/
rm -rf %{buildroot}%{buildroot}
# fix docu directories
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp -r COPYING README doc %{buildroot}%{_defaultdocdir}/%{name}
ln -s %{_datadir}/tkgate/doc %{buildroot}%{_defaultdocdir}/%{name}/doc
# fix script permissions
chmod +x %{buildroot}%{_datadir}/tkgate/scripts/tree.tcl
chmod +x %{buildroot}%{_datadir}/tkgate/scripts/elistbox.tcl
# move arch dependend file to default location
mv %{buildroot}%{_datadir}/tkgate/libexec/gsim %{buildroot}%{_libdir}/
ln -s %{_libdir}/gsim %{buildroot}%{_datadir}/tkgate/libexec/gsim
# install desktop file
install -Dm644 %{S:3} %{buildroot}%{_datadir}/pixmaps/%name.png
%if 0%{?suse_version}
%suse_update_desktop_file -i -n %name Education X-KDE-Edu-Teaching
# Remove zero-length 
rm -f %{buildroot}%{_datadir}/tkgate/scripts/dip.tcl
# reduce space, create symlinks
%fdupes -s %{buildroot}
%else
desktop-file-install %{S:2}
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc %{_defaultdocdir}/%{name}
%doc %{_mandir}/man1/tkgate.1x*
%doc %{_mandir}/man1/gmac.1x*
%{_datadir}/tkgate
%{_datadir}/applications/tkgate.desktop
%{_datadir}/pixmaps/tkgate.*
%{_bindir}/tkgate
%{_bindir}/gmac
%{_libdir}/tkgate
%{_libdir}/gsim

%changelog
* Thu Mar 27 2014 avvissu@yandex.ru
- Fix build error on openSUSE 13.1: The Tcl_Interp no longer
  contains the fields "result":
  + use temporary workaround USE_INTERP_RESULT
- Add tkgate-incorrect-fsf-address.diff
- Fix file-contains-date-and-time
- Removed zero-length ../scripts/dip.tcl
- Fix unresolvable dependencies for Fedora:
  + add RPM conditional tests for ?fedora
- Fix compilation error on Fedora: permission denied:
  + add $DESTDIR to make install
- Add desktop file for Fedora
* Sun Dec 16 2012 lars@linux-schulserver.de
- fix license to be in SPDX format
- specfile cleanup
* Fri Dec 25 2009 lars@linux-schulserver.de
- use libdir instead of libexecdir
* Sun Mar  8 2009 lars@linux-schulserver.de
- fix docdir link
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Wed Jul 16 2008 lars@linux-schulserver.de
- fix manpages (tkgate-manpages.patch)
- fix Imakefiles to honour the localdir
  (tkgate-honour-localdir.patch)
- fix shebang for wish (tkgate-elistbox.patch)
- change values in config.h via patch and specfile sed's
  (tkgate-config.h.patch)
- place tkgate in /usr/bin instead of /usr/X11R6/bin
* Mon Mar 17 2008 lars@linux-schulserver.de
- define man pages as %%doc
- run /sbin/ldconfig
* Thu Dec  6 2007 lars@linux-schulserver.de
- initial version 1.8.7
